﻿// Copyright (c) Microsoft Corporation. All rights reserved.
// Licensed under the MIT License. See License.txt in the project root for license information.

using Microsoft.Azure.Management.Resource.Fluent;
using Microsoft.Azure.Management.Resource.Fluent.Models;
using Microsoft.Azure.Management.Resource.Fluent.Core;
using Microsoft.Azure.Management.Resource.Fluent.Core.ResourceActions;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Threading.Tasks;

namespace Microsoft.Azure.Management.Resource.Fluent
{
    internal class DeploymentOperationImpl :
        IndexableRefreshableWrapper<IDeploymentOperation, DeploymentOperationInner>,
        IDeploymentOperation
    {
        private string resourceGroupName;
        private string deploymentName;

        private IDeploymentOperationsOperations client;

        internal DeploymentOperationImpl(DeploymentOperationInner innerModel, IDeploymentOperationsOperations client) : base(innerModel.Id, innerModel)
        {
            this.client = client;
            resourceGroupName = ResourceUtils.GroupFromResourceId(innerModel.Id);
            deploymentName = ResourceUtils.ExtractFromResourceId(innerModel.Id, "deployments");
        }

        #region Getters 

        public string OperationId
        {
            get
            {
                return Inner.OperationId;
            }
        }

        public string ProvisioningState
        {
            get
            {
                if (Inner.Properties == null)
                {
                    return null;
                }
                return Inner.Properties.ProvisioningState;
            }
        }

        public DateTime? Timestamp
        {
            get
            {
                if (Inner.Properties == null)
                {
                    return null;
                }
                return Inner.Properties.Timestamp;
            }
        }

        public string StatusCode
        {
            get
            {
                if (Inner.Properties == null)
                {
                    return null;
                }
                return Inner.Properties.StatusCode;
            }
        }

        public object StatusMessage
        {
            get
            {
                if (Inner.Properties == null)
                {
                    return null;
                }
                return Inner.Properties.StatusMessage;
            }
        }

        public TargetResource TargetResource
        {
            get
            {
                if (Inner.Properties == null)
                {
                    return null;
                }
                return Inner.Properties.TargetResource;
            }
        }

        #endregion

        #region Implementation of IRefreshable interface

        public override IDeploymentOperation Refresh()
        {
            var inner = client.Get(resourceGroupName, deploymentName, OperationId);
            SetInner(inner);
            return this;
        }

        #endregion
    }
}
